@@ -57,6 +57,8 @@ echo "RUN Linux_lib64.so --offset 0xdeadbeef00000000" | tee -a  ./test_output
 $RUN --binary ./Linux_lib64.so --offset 0xdeadbeef00000000 1>> ./test_output
 echo "RUN elf-ARMv7-ls --depth 5" | tee -a  ./test_output
 $RUN --binary ./elf-ARMv7-ls --depth 5 1>> ./test_output
+echo "RUN elf-ARMv7-ls --thumb --depth 5" | tee -a  ./test_output
+$RUN --binary ./elf-ARMv7-ls --thumb --depth 5 1>> ./test_output
 echo "RUN elf-ARM64-bash --depth 5" | tee -a  ./test_output
 $RUN --binary ./elf-ARM64-bash --depth 5 1>> ./test_output
 echo "RUN elf-PPC64-bash --depth 5" | tee -a  ./test_output
